/**
 * Created by Joker on 2017-08-17.
 */
import React, {Component} from 'react'
import {
    ActivityIndicator,
    FlatList,
    Image,
    RefreshControl,
    Text,
    View,
    Dimensions,
} from 'react-native'
import PropTypes from 'prop-types'
var width = Dimensions.get('window').width;
var height = Dimensions.get('window').width;
const defaultColor = "#00AEF3"
/**
 * @param onLoad 上拉加载
 * @param onRefresh 下拉刷新
 * @param renderItem 列表子组件
 * @param showBackGround 是否显示无数据背景
 * @param sepline 分割线样式
 * @param header 列表头部
 * @param nodata_message 无数据提示
 * @param scrollEnabled 是否可以滚动
 * @param columns 每行元素的列数
 * @param no_data_img 无数据提示图片
 * @param indicator_color 加载圈颜色*/
export default class SFListView extends Component {
    static propTypes = {
        onLoad: PropTypes.func,
        onRefresh: PropTypes.func,
        renderItem: PropTypes.func,
        showBackGround: PropTypes.bool,
        sepline: PropTypes.func,
        header: PropTypes.func,
        nodata_message: PropTypes.string,
        scrollEnabled: PropTypes.bool,
        columns: PropTypes.number,
        no_data_img: PropTypes.number,
        indicator_color:PropTypes.string,
    }
    static defaultProps={
        showBackGround:false,
        nodata_message:'暂无数据',
        scrollEnabled:true,
        columns:1,
        indicator_color:defaultColor,
    }

    constructor(props) {
        super(props)
        this.state = {
            data:[],
            isRefreshing: false,
            isLoading:false,
            canRefresh: true,
            footerloading: true,
            footertext: '',
            showfooter: true,
            footer: null,
            nodata_message: '暂无数据',
        }
    }

    componentWillMount() {
    }
    setRefreshing = (visible) => {
        this.setState({
            isRefreshing: visible
        })
    }
    canRefresh = (can) => {
        this.setState({
            canRefresh: can
        })
    }
    onRefresh = () => {
        this.setRefreshing(true)
        if (this.props.onRefresh != null) {
            this.props.onRefresh()
        }
    }
    setLoading=(visible)=>{
        this.setState({
            isLoading: visible
        })
    }

    render() {
        const state = this.state
        const props = this.props
        return (
            <FlatList
                data={state.data}
                extraData={state}
                keyExtractor={this._keyExtractor}
                renderItem={props.renderItem}
                ItemSeparatorComponent={props.sepline}
                ListEmptyComponent={this._backgroud}
                onEndReachedThreshold={0.5}
                onEndReached={this.onEnd}
                ListHeaderComponent={props.header}
                ListFooterComponent={this._footer}
                scrollEnabled={props.scrollEnabled}
                numColumns={props.columns}
                refreshControl={state.canRefresh ?
                    <RefreshControl
                        refreshing={state.isRefreshing}
                        onRefresh={this.onRefresh}
                        tintColor={props.indicator_color}
                        title="正在刷新数据..."
                        colors={[props.indicator_color]}
                        progressBackgroundColor="#ffffff"
                    /> : null}
            />
        )
    }
    setData=(data,callback)=>{
        this.setState({
            data:data
        },callback)
    }
    addData=(data,callback)=>{
        this.setState({
            data:this.state.data.concat(data)
        },callback)
    }
    clearData=(callback)=>{
        this.setState({
            data:[]
        },callback)
    }

    onEnd = () => {
        if (this.props.onLoad != null) {
            this.setLoading(true)
            this.props.onLoad()
        }
    }
    _keyExtractor = (item, index) => ""+index
    _backgroud = () => {
        if (this.props.showBackGround) {
            if(this.props.no_data_img == null){
                return (
                    <View style={{
                        width: width,
                        height: height - 104,
                        alignItems: 'center'
                    }}>
                        <Text style={{
                            fontSize: 15,
                            color: '#696969',
                            marginTop: 10
                        }}>{this.state.nodata_message}</Text>
                    </View>
                )
            }
            return (
                <View style={{
                    width: width,
                    height: height - 104,
                    alignItems: 'center'
                }}>
                    <Image style={{
                        width: 120,
                        height: 120,
                        marginTop: 50
                    }}
                           source={this.state.no_data_img}
                           resizeMode={'contain'}/>
                    <Text style={{
                        fontSize: 15,
                        color: '#696969',
                        marginTop: 10
                    }}>{this.state.nodata_message}</Text>
                </View>
            )
        }
        else {
            return null;
        }
    }
    _footer = () => {
        if(this.state.isLoading){
            return (
                <View style={{
                    width: width,
                    height: 50,
                    alignItems: 'center',
                    justifyContent: 'center',
                    flexDirection: 'row'
                }}>
                    <ActivityIndicator
                        animating={this.state.footerloading}
                        color={this.props.indicator_color}
                        size={'small'}/>
                    <Text>{this.state.footertext}</Text>
                </View>
            )

        }else{
            return null
        }

    }
}